/**************************************************************************
**       Title: RGB Color class
**    $RCSfile: RGBColor.hh,v $
**   $Revision: 1.2 $$Name:  $
**       $Date: 2001/04/30 16:51:25 $
**   Copyright: GPL $Author: ronneber $
** Description:
**
**    
**
**-------------------------------------------------------------------------
**
**  $Log: RGBColor.hh,v $
**  Revision 1.2  2001/04/30 16:51:25  ronneber
**  corrected prototype of print() method
**
**  Revision 1.1  2001/04/06 15:12:46  haasdonk
**  slight modification
**
**  Revision 1.2  2001/03/31 17:52:43  ronneber
**  - many changes, see file 'Kommentare' for details
**
**
**************************************************************************/
#ifndef RGBCOLOR_HH
#define RGBCOLOR_HH

typedef unsigned char uchar;

/*======================================================================*/
/*!
 *  \class  RGBColor RGBColor.hh
 *  \brief The RGBColor class specifies a color with red green blue
 *         components 
 *
 *  it contains all methods for calculating with colors
 */
/*======================================================================*/
class RGBColor 
{
public:

  /*-----------------------------------------------------------------------
   *  Fixed colors by name
   *-----------------------------------------------------------------------*/
  static const RGBColor White;
  static const RGBColor Red;
  static const RGBColor Green; 
  static const RGBColor Blue; 
  static const RGBColor Black;
  static const RGBColor Yellow; 
  static const RGBColor Magenta; 
  static const RGBColor Cyan;

  /*======================================================================*/
  /*! 
   *   Default Constructor creating a black (0,0,0) Color
   */
  /*======================================================================*/
  RGBColor ();
  
  /*======================================================================*/
  /*! 
   *    Constructor for creating an abitrary color
   *
   *   \param red     red component for color (0-255)
   *   \param green   green component for color (0-255)
   *   \param blue    blue component for color (0-255)
   */
  /*======================================================================*/
  RGBColor (uchar red, uchar green, uchar blue); 
  
  /*======================================================================*/
  /*! 
   *   Constructor for creating an gray color (where red = green = blue)
   *
   *   \param gray   gray value (0-255)
   */
  /*======================================================================*/
  RGBColor (uchar gray);
  
  uchar red() const;
  uchar green() const;
  uchar blue() const;
  
  void set(uchar red, uchar green, uchar blue);


  /*! print RGB value to stdout, e.g. (123, 42,  0)  */
  void print() const;
   
  RGBColor& operator +=(const RGBColor& c);
  RGBColor& operator +=(uchar gray);
  RGBColor& operator -=(const RGBColor& c);
  RGBColor& operator -=(uchar gray);
  RGBColor& operator *=(float factor); 

  
  bool operator ==(const RGBColor& c) const;
  bool operator !=(const RGBColor& c) const;
  
  
protected:
  
  uchar rc, gc, bc;
};    


RGBColor operator ! (const RGBColor& c);
RGBColor operator + (const RGBColor& c1, const RGBColor& c2);
RGBColor operator - (const RGBColor& c1, const RGBColor& c2);
RGBColor operator * (const RGBColor& c1, float factor); 
RGBColor operator * (float factor, const RGBColor& c1); 


#include "RGBColor.icc"

#endif 
